@@ -2,3 +2,5 @@ from ekp_sdk.ui.components.chart import *
 from ekp_sdk.ui.components.link import *
 from ekp_sdk.ui.components.others import *
 from ekp_sdk.ui.components.tabs import *
+from ekp_sdk.ui.components.form import *
+from ekp_sdk.ui.components.input import *
