@@ -1,4 +1,6 @@
 from ekp_sdk.ui.rpc.commify import *
 from ekp_sdk.ui.rpc.format_mask_address import *
 from ekp_sdk.ui.rpc.navigate import *
-from ekp_sdk.ui.rpc.remove_form_record import *
\ No newline at end of file
+from ekp_sdk.ui.rpc.remove_form_record import *
+from ekp_sdk.ui.rpc.sum import *
+from ekp_sdk.ui.rpc.count import *
\ No newline at end of file
